The functions below are methods for PCR objects
# S3 method for PCR
fitted(object, pc = object$pc, ...)
# S3 method for PCR
plot(x, type = c("path", "gaic"),
labels = TRUE, cex = 0.8, ...)
# S3 method for PCR
coef(object, param = c("gamma", "beta"),
pc = object$pc, ...)
# S3 method for PCR
predict(object, newdata = NULL,
pc = object$pc, ...)
# S3 method for PCR
vcov(object, pc = object$pc,
type = c("vcov", "cor", "se", "all"),
...)
an PCR object
the number of PC (by default the one minimising the local GAIC)
for plot() whether to plot the path of coefficients or the path of GAIC and for vcov() whether variance covariance, correlation or se's
getting the gamma or the beta coefficients
new data for prediction
whether to plot the labels of the variables
the size of the text when plotting the labels of the variables
for extra arguments
Mikis Stasinopoulos d.stasinopoulos@londonmet.ac.uk, Bob Rigby and Fernada De Bastiani
Rigby, R. A. and Stasinopoulos D. M. (2005). Generalized additive models for location, scale and shape, (with discussion), Appl. Statist., 54, part 3, pp 507-554.
Rigby, R. A., Stasinopoulos, D. M., Heller, G. Z., and De Bastiani, F. (2019) Distributions for modeling location, scale, and shape: Using GAMLSS in R, Chapman and Hall/CRC. An older version can be found in https://www.gamlss.com/.
Stasinopoulos D. M. Rigby R.A. (2007) Generalized additive models for location scale and shape (GAMLSS) in R. Journal of Statistical Software, Vol. 23, Issue 7, Dec 2007, https://www.jstatsoft.org/v23/i07/.
Stasinopoulos D. M., Rigby R.A., Heller G., Voudouris V., and De Bastiani F., (2017) Flexible Regression and Smoothing: Using GAMLSS in R, Chapman and Hall/CRC.
(see also https://www.gamlss.com/).
fitPCR